#
# example of use of pyPRM
#
from collections import OrderedDict
from matplotlib import pyplot as plt

# class to create standardized plots
class stereographic :
   def __init__(self,figsize=[12,12]) :
      self._uxyz=None
      self.h=None
   def project(self,xyz) :
      theta=np.arctan2(xyz[:,1],xyz[:,0])
      radius=np.arccos(xyz[:,2])
      return theta,radius
   @property
   def uxyz(self) :
      return self._uxyz
   @uxyz.setter
   def uxyz(self,this) :
      self._uxyz=this
   def uplot(self) :
      x=np.arange(10)/10.
      self.h=plt.polar(x*2*pi/10,x*0+1.2)
      self.h[0].set_visible(False)
      for k in self.uxyz :
         _utheta,_uradius=self.project(k)
         plt.polar(_utheta,_uradius,color='gray')
   def plot(self,xyz,**karg) :
      theta,radius=self.project(xyz)
      plt.polar(theta[0],radius[0],'o',markersize=8,color='gray')
      plt.polar(theta[1],radius[1],'o',markersize=6,color='gray')
      plt.polar(theta,radius,**karg)
      plt.show()

from PyPRM import *

#
# list of Theta,Phi positions
CT_P=np.array([
      [0.,0.]
   ,[30.,0.]
   ,[60.,0.]
   ,[30.,90.]
   ,[30.,180.]
   ,[30.,270.]
   ])

# the first case, an ideal telescope
pm0I=PRM0(ideal=True)
R=OrderedDict()
R['Ideal']=pm0I(CT_P)

# camera roll
pm0roll=PRM0(ideal=True)
pm0roll.roll=45
pm0roll.commit()
R['roll']=pm0roll(CT_P)

# camera pan
pm0pan=PRM0(ideal=True)
pm0pan.pan=10
pm0pan.commit()
R['pan']=pm0pan(CT_P)

# camera tilt
pm0tilt=PRM0(ideal=True)
pm0tilt.tilt=10
pm0tilt.commit()
R['tilt']=pm0tilt(CT_P)

# tiltFork
pm0tiltFork=PRM0(ideal=True)
pm0tiltFork.tiltFork=10
pm0tiltFork.commit()
R['tiltFork']=pm0tiltFork(CT_P)

# ctheta0
pm0ctheta0=PRM0(ideal=True)
pm0ctheta0.ctheta0=10
pm0ctheta0.commit()
R['ctheta0']=pm0ctheta0(CT_P)

# cphi0
pm0cphi0=PRM0(ideal=True)
pm0cphi0.cphi0=10
pm0cphi0.commit()
R['cphi0']=pm0cphi0(CT_P)

# zVAX
pm0zVAX=PRM0(ideal=True)
pm0zVAX.zVAX=10
pm0zVAX.commit()
R['zVAX']=pm0zVAX(CT_P)

# omegaVAX
pm0omegaVAX=PRM0(ideal=True)
pm0omegaVAX.omegaVAX=10
pm0omegaVAX.commit()
R['omegaVAX']=pm0omegaVAX(CT_P)

#
# rotates a 4 points fow
# FOW trace
w=6; sw = np.sin(np.deg2rad(w))
h=2; sh = np.sin(np.deg2rad(h))
z=(1-sw**2-sh**2)**0.5
V=np.array([
    [ sw, sh, z]
   ,[-sw, sh, z]
   ,[-sw,-sh, z]
   ,[ sw,-sh, z]
   ,[ sw, sh, z]
   ])

plt.close('all')
#
std=stereographic()
std.uxyz=[np.array([k.dot(k1) for k1 in V]) for k in R['Ideal']]
#
for karg in ['Ideal','roll','pan','tilt','tiltFork','ctheta0','cphi0','zVAX','omegaVAX'] :
   plt.figure(figsize=[8,8])
   std.uplot()
   for k in R[karg] :
      Vr=np.array([k.dot(k1) for k1 in V])
      std.plot(Vr)
   plt.title(karg)
   plt.savefig('/tmp/polar_%s.pdf'%karg,dpi=plt.gcf().get_dpi())
   plt.show()
